![alt text](https://chivo.cl/media/service-images/2017-12-28_09.45.07.jpg)

Smoothy
=======

This python package provides an easy interface and I/O operations for using astronomical libraries over Jupyter notebooks (and in general over Python ecosystems).

The source is publicly managed by the github service.

Documentation
-------------

**Smoothy**'s documentation for visualization, FITS management and UPI (User Programmatic Interface) usage can be found in [Read The Docs](http://smoothy.readthedocs.io/).


Installation
------------

In order to install Smoothy, clone this repository and run:

``
python setup.py install
``
